clusters_MajKm: clustering results of the majorized k-mean algorithm
Description
clusters data into two clusters with a majorization k-means This functionis use a hybrid of the k-means and the majorizaion-minimazation method to cluster the data and exports the clustering results as well as the sum of square (SS) of clustering
Arguments
x
matrix of data (dim 1: samples (must be equal to dim 1 of X), dim 2: attributes (must be equal to dim 2 of X))
k
number of clusters ( this version considers 2 clusters )
La
the tunnung parameter
Value
sum of square (SS) of clustring and the 'delta' (difference of two successive majorization function).